Translation guide — Invenio 3.1.2 documentation

# Translation guide

Invenio has been translated to more than 25 languages.

## Transifex

All Invenio internationalisation and localisation efforts are happening on the Transifex collaborative localisation platform.

You can start by exploring Invenio project dashboard on Transifex.

Invenio project consists of many resource files which can be categorised as follows:

- `invenio-maint10-messages` contains phrases for Invenio 1.0 legacy release series

- `invenio-maint11-messages` contains phrases for Invenio 1.1 legacy release series

- `invenio-maint12-messages` contains phrases for Invenio 1.2 legacy release series

- `invenio-xxx-messages` contains phrases for Invenio 3.0 `invenio-xxx` module

We follow the usual Transifex localisation workflow that is extensively documented.

## Translators

All contributions with translating phrases or with reviewing translations are very appreciated!

Please read Getting started as a translator and join Invenio project on Transifex.

## Developers

Please see dedicated invenio-i18n documentation.